==> antiright-2.99.6.tar.bz2: antiright/gtkshell/gtkshell.h <==
/*
  AntiRight
  (c) 2002-2006 Jeffrey Bedard
  antiright@gmail.com

  This file is part of AntiRight.

  AntiRight is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  AntiRight is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with AntiRight; if not, write to the Free Software
  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
*/
#ifndef GSH_GTKSHELL_H
#define GSH_GTKSHELL_H

#include <gtk/gtk.h>
#include <errno.h>
#include "../libantiright/library.h"

#include "arguments.h"
#include "options.h"
#include "callbacks.h"
#include "updated.h"
#include "label.h"
#include "button.h"
#include "text.h"
#include "updated_label.h"
#include "updated_progress.h"
#include "option_options.h"
#include "updated_options.h"
#include "add_options.h"
#include "dialog_options.h"
#include "file_dialog.h"
#include "row.h"
#include "containers.h"

GtkWidget      *gsh_window;
GtkWidget      *gsh_hbox;
GtkWidget      *gsh_vbox;
GtkWidget      *gsh_label;


void
gsh_init(int *argc, char ***argv);

void
gsh_set_geometry();

void
gsh_check_and_set_geometry();

GtkWidget *
gsh_create_main_window();

#endif

==> antiright-2.99.7.tar.bz2: antiright/gtkshell/gtkshell.h <==
/*
  AntiRight
  (c) 2002-2006 Jeffrey Bedard
  antiright@gmail.com

  This file is part of AntiRight.

  AntiRight is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  AntiRight is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with AntiRight; if not, write to the Free Software
  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
*/
#ifndef GSH_GTKSHELL_H
#define GSH_GTKSHELL_H

#include <gtk/gtk.h>
#include <errno.h>
#include "../libantiright/library.h"

struct GSH_Flags
{
    gboolean dont_scroll;
    gboolean button_exits;
    gboolean updating;
};

struct GSH_Rows
{
    GtkWidget *h;
    GtkWidget *v;
    unsigned int row;
    unsigned int rows;
};

struct GSH
{
    GtkWidget *window;
    GtkWidget *scrolled_window;
    struct GSH_Rows rows;
    struct GSH_Flags flags;
    GtkWidget *label;
    GtkWidget *button;
    gchar *geometry;
    unsigned int update_period;
};

#include "arguments.h"
#include "options.h"
#include "callbacks.h"
#include "updated.h"
#include "label.h"
#include "button.h"
#include "text.h"
#include "updated_label.h"
#include "updated_progress.h"
#include "option_options.h"
#include "updated_options.h"
#include "add_options.h"
#include "dialog_options.h"
#include "file_dialog.h"
#include "row.h"
#include "containers.h"
#include "geometry.h"

void
gsh_stack_init(struct GSH *gsh, int *argc, char ***argv);

struct GSH *
gsh_init(int *argc, char ***argv);

GtkWidget *
gsh_create_main_window();

#endif
